@@ -26,9 +26,6 @@ def get_name():
     return "Disables the Clock Display"
 
 class NoClock(clock.Clock):
-    def __init__(self, drawing_area):
-        clock.Clock.__init__(self, drawing_area)
-
     def draw_clock(self):
         pass
 
